@@ -3,11 +3,7 @@ package PLS;
 use strict;
 use warnings;
 
-our $VERSION = '0.5';
-
-1;
-
-__END__
+our $VERSION = '0.6';
 
 =head1 NAME
 
@@ -97,3 +93,7 @@ Copyright 2021 Marc Reisner
 
 This library is free software; you may redistribute it and/or
 modify it under the same terms as Perl itself.
+
+=cut
+
+1;
